@@ -141,7 +141,7 @@ static inline void data_diagramelement_trace ( const data_diagramelement_t *this
  *  \param this_ pointer to own object attributes
  *  \return attribute id, DATA_ROW_ID_VOID if this_ is not valid
  */
-static inline data_row_id_t data_diagramelement_get_id ( const data_diagramelement_t *this_ );
+static inline data_row_id_t data_diagramelement_get_row_id ( const data_diagramelement_t *this_ );
 
 /*!
  *  \brief sets the attribute id
@@ -149,7 +149,7 @@ static inline data_row_id_t data_diagramelement_get_id ( const data_diagrameleme
  *  \param this_ pointer to own object attributes
  *  \param id new id of this object
  */
-static inline void data_diagramelement_set_id ( data_diagramelement_t *this_, data_row_id_t id );
+static inline void data_diagramelement_set_row_id ( data_diagramelement_t *this_, data_row_id_t id );
 
 /*!
  *  \brief gets the data_id derived from the id attribute
@@ -165,7 +165,7 @@ static inline data_id_t data_diagramelement_get_data_id ( const data_diagramelem
  *  \param this_ pointer to own object attributes
  *  \return attribute diagram_id, DATA_ROW_ID_VOID if the referenced diagram is not valid
  */
-static inline data_row_id_t data_diagramelement_get_diagram_id ( const data_diagramelement_t *this_ );
+static inline data_row_id_t data_diagramelement_get_diagram_row_id ( const data_diagramelement_t *this_ );
 
 /*!
  *  \brief gets the data_id derived from the attribute diagram_id
@@ -181,7 +181,7 @@ static inline data_id_t data_diagramelement_get_diagram_data_id ( const data_dia
  *  \param this_ pointer to own object attributes
  *  \return attribute classifier_id, DATA_ROW_ID_VOID if the referenced classifier is not valid
  */
-static inline data_row_id_t data_diagramelement_get_classifier_id ( const data_diagramelement_t *this_ );
+static inline data_row_id_t data_diagramelement_get_classifier_row_id ( const data_diagramelement_t *this_ );
 
 /*!
  *  \brief gets the data_id derived from the attribute classifier_id
@@ -197,7 +197,7 @@ static inline data_id_t data_diagramelement_get_classifier_data_id ( const data_
  *  \param this_ pointer to own object attributes
  *  \return attribute focused_feature_id, DATA_ROW_ID_VOID if there is no focused feature
  */
-static inline data_row_id_t data_diagramelement_get_focused_feature_id ( const data_diagramelement_t *this_ );
+static inline data_row_id_t data_diagramelement_get_focused_feature_row_id ( const data_diagramelement_t *this_ );
 
 /*!
  *  \brief sets the attribute focused_feature_id
@@ -205,7 +205,7 @@ static inline data_row_id_t data_diagramelement_get_focused_feature_id ( const d
  *  \param this_ pointer to own object attributes
  *  \param focused_feature_id new attribute focused_feature_id
  */
-static inline void data_diagramelement_set_focused_feature_id ( data_diagramelement_t *this_, data_row_id_t focused_feature_id );
+static inline void data_diagramelement_set_focused_feature_row_id ( data_diagramelement_t *this_, data_row_id_t focused_feature_id );
 
 /*!
  *  \brief gets the data_id derived from the attribute focused_feature_id
