@@ -129,7 +129,7 @@ int io_export_interaction_traversal_private_walk_diagram ( io_export_interaction
 
         if ( is_interaction_type )
         {
-            TRACE_INFO_INT("exporting diagram as interaction, id:",data_diagram_get_id(diag_ptr));
+            TRACE_INFO_INT("exporting diagram as interaction, id:",data_diagram_get_row_id(diag_ptr));
 
             /* add this classifier to the already written elements */
             write_err |= universal_array_list_append( (*this_).written_id_set, &diagram_id );
@@ -242,17 +242,16 @@ int io_export_interaction_traversal_private_look_for_focused_feature ( io_export
         /* get feature */
         const data_feature_t *feature;
         feature = data_visible_set_get_feature_const ( diagram_data, index );
-        
-        const data_id_t classifier_id = data_feature_get_classifier_data_id ( feature );
          
         if (( feature != NULL ) && ( data_feature_is_valid( feature ) ))
         {
+            const data_id_t classifier_id = data_feature_get_classifier_data_id ( feature );
             const data_id_t feat_id = data_feature_get_data_id( feature );
             if ( data_id_equals( &focused_feature_id, &feat_id ) )
             {
                 const bool is_visible = data_rules_diagram_shows_feature ( &((*this_).filter_rules),
                                                                            diagram_data,
-                                                                           data_feature_get_id( feature )
+                                                                           data_feature_get_row_id( feature )
                                                                          );
                 const bool is_lifeline
                     =( DATA_FEATURE_TYPE_LIFELINE == data_feature_get_main_type( feature ) );
@@ -363,18 +362,26 @@ int io_export_interaction_traversal_private_iterate_feature_relationships ( io_e
                                                                       );
                     if ( is_message )
                     {
-                        write_err |= xmi_ineraction_writer_assemble_relationship( &((*this_).interaction_writer), 
-                                                                                  interaction_id,
-                                                                                  DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake parent type */
-                                                                                  relation
-                                                                                );
+                        write_err |= xmi_interaction_writer_assemble_relationship( &((*this_).interaction_writer), 
+                                                                                   interaction_id,
+                                                                                   DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake parent type */
+                                                                                   relation,
+                                                                                   DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake from classifier type */
+                                                                                   DATA_FEATURE_TYPE_LIFELINE,  /* guess from feature type */
+                                                                                   DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake to classifier type */
+                                                                                   DATA_FEATURE_TYPE_LIFELINE  /* guess to feature type */
+                                                                                 );
                     }
                     else
                     {
                         write_err |= xmi_element_writer_assemble_relationship( (*this_).element_writer, 
                                                                                DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake parent type */
                                                                                false,  /* parent_is_source: parent is faked */
-                                                                               relation
+                                                                               relation,
+                                                                               DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake from classifier type */
+                                                                               DATA_FEATURE_TYPE_LIFELINE,  /* guess from feature type */
+                                                                               DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake to classifier type */
+                                                                               DATA_FEATURE_TYPE_LIFELINE  /* guess to feature type */
                                                                              );
                     }
                     write_err |= xmi_element_writer_end_relationship( (*this_).element_writer, 
