@@ -2,6 +2,8 @@
 
 #include "xmi/xmi_element_part.h"
 
+/* constants naming scheme: XMI_ELEMENT_PART_<XMI-CONTEXT>_<LITERAL> */
+
 const char * const XMI_ELEMENT_PART_FALLBACK_NESTING_ELEMENT
     = "packagedElement";
 
@@ -23,6 +25,12 @@ const char * const XMI_ELEMENT_PART_PROPERTY_ASSOCIATION_ATTRIBUTE
 const char * const XMI_ELEMENT_PART_PROPERTY_TYPE_ELEMENT
     = "type";
 
+const char * const XMI_ELEMENT_PART_PROPERTY_CLASS_ELEMENT
+    = "class";
+
+const char * const XMI_ELEMENT_PART_PROPERTY_INTERFACE_ELEMENT
+    = "interface";
+
 const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_ATTRIBUTE
     = "aggregation";
 
@@ -32,6 +40,12 @@ const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_SHARED
 const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_COMPOSITE
     = "composite";
 
+const char * const XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC
+    = "MessageOccurrenceSpecification";
+
+const char * const XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED
+    = "covered";
+
 
 /*
 Copyright 2020-2020 Andreas Warnke
