@@ -182,11 +182,12 @@ int xmi_element_writer_start_classifier( xmi_element_writer_t *this_,
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
         /* determine nesting tag */
+        const data_classifier_type_t classifier_type = data_classifier_get_main_type(classifier_ptr);
         const char* nesting_property;
         const int nesting_err
             = xmi_type_converter_get_xmi_nesting_property_of_classifier( &((*this_).xmi_types),
                                                                          parent_type,
-                                                                         data_classifier_get_main_type(classifier_ptr),
+                                                                         classifier_type,
                                                                          &nesting_property
                                                                        );
         if ( nesting_err != 0 )
@@ -199,12 +200,11 @@ int xmi_element_writer_start_classifier( xmi_element_writer_t *this_,
             data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_CLASSIFIER, DATA_STAT_SERIES_WARNING );
             /* inform the user via an XML comment: */
             const data_id_t classifier_id = data_classifier_get_data_id(classifier_ptr);
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- COMMENT ON UML-CONFORMANCE: Unsuitable nested type of " );
-            export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), classifier_id );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " -->" );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- PROPOSAL: Pack the " );
-            export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), classifier_id );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " into a more suitable container or change its type -->" );
+            export_err |= xmi_atom_writer_report_illegal_container( &((*this_).atom_writer),
+                                                                    classifier_id,
+                                                                    classifier_type,
+                                                                    parent_type
+                                                                  );
             /* use a fallback */
             nesting_property = XMI_ELEMENT_PART_FALLBACK_NESTING_ELEMENT;
         }
@@ -239,7 +239,7 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
     const xmi_element_info_t *classifier_info
         = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard,
                                                classifier_type,
-                                               (parent_type==DATA_CLASSIFIER_TYPE_STATE)
+                                               parent_type
                                              );
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
@@ -264,6 +264,11 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), classifier_name );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_END );
         }
+        else
+        {
+            /* only comments do not have names */
+            assert( classifier_type == DATA_CLASSIFIER_TYPE_COMMENT );
+        }
 
         if ( NULL != xmi_element_info_get_additional_properties( classifier_info ) )
         {
@@ -290,19 +295,16 @@ int xmi_element_writer_assemble_classifier( xmi_element_writer_t *this_,
 /* TODO */                                                                 classifier_stereo
 /* TODO */                                                               );
         }
-        if ( ! xmi_element_info_is_a_named_element( classifier_info ) )
-        {
-            export_err |= xmi_atom_writer_write_xmi_comment( &((*this_).atom_writer),
-                                                             classifier_id,
-                                                             "name",
-                                                             classifier_name
-                                                           );
-        }
         if ( classifier_type == DATA_CLASSIFIER_TYPE_COMMENT )
         {
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI2_UML_COMMENT_BODY_START );
             xml_writer_increase_indent ( &((*this_).xml_writer) );
 
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
+            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), classifier_name );
+
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n" );
+            
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
             export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), classifier_descr );
 
@@ -487,7 +489,7 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
     const data_id_t feature_id = data_feature_get_data_id( feature_ptr );
     const data_feature_type_t feature_type = data_feature_get_main_type( feature_ptr );
     const xmi_element_info_t *feature_info
-        = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, feature_type );
+        = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, feature_type, XMI_DIRECTION_UNSPECIFIED, parent_type );
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
@@ -506,12 +508,11 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
             /* update export statistics */
             data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_FEATURE, DATA_STAT_SERIES_WARNING );
             /* inform the user via an XML comment: */
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- COMMENT ON UML-CONFORMANCE: Unsuitable parent type of " );
-            export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), feature_id );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " -->" );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- PROPOSAL: Pack the " );
-            export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), feature_id );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " into a more suitable container or change its type -->" );
+            export_err |= xmi_atom_writer_report_illegal_parent( &((*this_).atom_writer),
+                                                                 feature_id,
+                                                                 feature_type,
+                                                                 parent_type
+                                                               );
         }
 
         /* write nesting tag */
@@ -524,7 +525,9 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
         const char* f_type = xmi_type_converter_get_xmi_type_of_feature ( &((*this_).xmi_types),
+                                                                          parent_type,
                                                                           feature_type,
+                                                                          XMI_DIRECTION_UNSPECIFIED,
                                                                           XMI_SPEC_UML
                                                                         );
         export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), f_type );
@@ -532,7 +535,7 @@ int xmi_element_writer_start_feature( xmi_element_writer_t *this_,
 
         /* write id attribute */
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_START );
-        export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer),feature_id );
+        export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), feature_id );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_END );
 
         /* write name attribute */
@@ -657,6 +660,8 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
                                                  relation_type,
                                                  (parent_type==DATA_CLASSIFIER_TYPE_STATE)
                                                );
+    const bool is_annotated_element 
+        = (( parent_type == DATA_CLASSIFIER_TYPE_COMMENT )&&( relation_type == DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY ));
 
     if ( (*this_).mode == IO_WRITER_PASS_BASE )
     {
@@ -675,15 +680,11 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
             /* update export statistics */
             data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
             /* inform the user via an XML comment: */
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- COMMENT ON UML-CONFORMANCE: Unsuitable parent type of " );
-            export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), relation_id );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " -->" );
-            {
-                export_err |= xml_writer_write_plain ( &((*this_).xml_writer), "\n<!-- PROPOSAL: Change either the " );
-                export_err |= xml_writer_write_plain_id( &((*this_).xml_writer), relation_id );
-                export_err |= xml_writer_write_plain ( &((*this_).xml_writer), " or the classifier at its source end to a more suitable type -->" );
-                /* classifier types at target end are not yet checked */
-            }
+            export_err |= xmi_atom_writer_report_illegal_location( &((*this_).atom_writer),
+                                                                   relation_id,
+                                                                   relation_type,
+                                                                   parent_type
+                                                                 );
             /* use a fallback */
             nesting_property = XMI_ELEMENT_PART_FALLBACK_NESTING_ELEMENT;
         }
@@ -693,36 +694,55 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), nesting_property );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
 
-        /* write type attribute */
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
-        const char* r_type = xmi_type_converter_get_xmi_type_of_relationship ( &((*this_).xmi_types),
-                                                                               parent_type,
-                                                                               relation_type,
-                                                                               XMI_SPEC_UML
-                                                                             );
-        export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), r_type );
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_END );
-
-        /* write id attribute */
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_START );
-        export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer),relation_id );
-        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_END );
-
-        /* write name attribute */
-        if ( xmi_element_info_is_a_named_element( relation_info ) )
+        if ( is_annotated_element )
         {
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_START );
-            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), relation_name );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_END );
+            const data_id_t to_classifier_id = data_relationship_get_to_classifier_data_id( relation_ptr );
+            const data_id_t to_feature_id = data_relationship_get_to_feature_data_id( relation_ptr );
+            
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
+            if ( data_id_is_valid( &to_feature_id ) )
+            {
+                export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_feature_id );
+            }
+            else
+            {
+                export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_classifier_id );
+            }
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_END );
         }
-
-        if ( NULL != xmi_element_info_get_additional_properties( relation_info ) )
+        else
         {
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer),
-                                                   xmi_element_info_get_additional_properties( relation_info )
-                                                 );
-            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
+            /* write type attribute */
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_START );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_NS_UML );
+            const char* r_type = xmi_type_converter_get_xmi_type_of_relationship ( &((*this_).xmi_types),
+                                                                                   parent_type,
+                                                                                   relation_type,
+                                                                                   XMI_SPEC_UML
+                                                                                 );
+            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), r_type );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_TYPE_END );
+
+            /* write id attribute */
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_START );
+            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer),relation_id );
+            export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_ID_END );
+
+            /* write name attribute */
+            if ( xmi_element_info_is_a_named_element( relation_info ) )
+            {
+                export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_START );
+                export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), relation_name );
+                export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_NAME_END );
+            }
+
+            if ( NULL != xmi_element_info_get_additional_properties( relation_info ) )
+            {
+                export_err |= xml_writer_write_plain ( &((*this_).xml_writer),
+                                                       xmi_element_info_get_additional_properties( relation_info )
+                                                     );
+                export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
+            }
         }
 
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_START_TAG_END );
@@ -791,7 +811,11 @@ int xmi_element_writer_start_relationship( xmi_element_writer_t *this_,
 int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
                                               data_classifier_type_t parent_type,
                                               bool parent_is_source,
-                                              const data_relationship_t *relation_ptr )
+                                              const data_relationship_t *relation_ptr,
+                                              data_classifier_type_t from_c_type,
+                                              data_feature_type_t from_f_type,
+                                              data_classifier_type_t to_c_type,
+                                              data_feature_type_t to_f_type )
 {
     TRACE_BEGIN();
     assert ( NULL != relation_ptr );
@@ -803,8 +827,10 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
     const size_t relation_descr_len = utf8string_get_length(relation_descr);
     const data_id_t from_classifier_id = data_relationship_get_from_classifier_data_id( relation_ptr );
     const data_id_t from_feature_id = data_relationship_get_from_feature_data_id( relation_ptr );
+    const data_id_t from_end_id = data_id_is_valid( &from_feature_id ) ? from_feature_id : from_classifier_id;
     const data_id_t to_classifier_id = data_relationship_get_to_classifier_data_id( relation_ptr );
     const data_id_t to_feature_id = data_relationship_get_to_feature_data_id( relation_ptr );
+    const data_id_t to_end_id = data_id_is_valid( &to_feature_id ) ? to_feature_id : to_classifier_id;
     const data_relationship_type_t relation_type = data_relationship_get_main_type( relation_ptr );
     const xmi_element_info_t *relation_info
         = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard,
@@ -813,14 +839,20 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
                                                );
     /* evaluate if xmi requires to generate fake properties */
     const bool fake_property_ends = xmi_element_info_is_a_association( relation_info );
+    const bool fake_property_at_from_end 
+        = fake_property_ends && (( from_f_type !=  DATA_FEATURE_TYPE_PROPERTY )&&( from_f_type != DATA_FEATURE_TYPE_PORT ));
+    const bool fake_property_at_to_end 
+        = fake_property_ends && (( to_f_type != DATA_FEATURE_TYPE_PROPERTY )&&( to_f_type != DATA_FEATURE_TYPE_PORT ));
     /* check if suppress source end */
     const bool suppress_source 
         = (( relation_type == DATA_RELATIONSHIP_TYPE_UML_GENERALIZATION ) 
         || ( relation_type == DATA_RELATIONSHIP_TYPE_UML_EXTEND ) 
         || ( relation_type == DATA_RELATIONSHIP_TYPE_UML_INCLUDE ))
         && parent_is_source;
+    const bool is_annotated_element 
+        = (( parent_type == DATA_CLASSIFIER_TYPE_COMMENT )&&( relation_type == DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY ));
 
-    if ( (*this_).mode == IO_WRITER_PASS_BASE )
+    if (( (*this_).mode == IO_WRITER_PASS_BASE )&&( ! is_annotated_element ))
     {
         if ( 0 != relation_descr_len )
         {
@@ -834,82 +866,120 @@ int xmi_element_writer_assemble_relationship( xmi_element_writer_t *this_,
         /* source */
         if ( ! suppress_source )
         {
+            /* determine from type tag */
+            const char* from_type_tag;
+            const int from_type_err
+                = xmi_type_converter_get_xmi_from_property_of_relationship ( &((*this_).xmi_types),
+                                                                             parent_type,
+                                                                             relation_type,
+                                                                             from_c_type,
+                                                                             from_f_type,
+                                                                             &from_type_tag
+                                                                           );
+            if ( from_type_err != 0 )
+            {
+                /* The caller requested to write a relationship of illegal source end type */
+                TRACE_INFO("xmi_element_writer: request to write a relationship connecting an illegal source end type!")
+                /* update export statistics */
+                data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
+                /* inform the user via an XML comment: */
+                export_err |= xmi_atom_writer_report_illegal_relationship_end ( &((*this_).atom_writer),
+                                                                                relation_id,
+                                                                                relation_type,
+                                                                                parent_type,
+                                                                                true /* = from_end */,
+                                                                                from_c_type,
+                                                                                from_f_type
+                                                                              );                
+            }
+            
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
-            const char* from_type = xmi_type_converter_get_xmi_from_property_of_relationship ( &((*this_).xmi_types),
-                                                                                               parent_type,
-                                                                                               relation_type
-                                                                                             );
-            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), from_type );
+            export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), from_type_tag );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
 
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
-            if ( data_id_is_valid( &from_feature_id ) )
-            {
-                export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_feature_id );
-            }
-            else if ( fake_property_ends )
+            if ( fake_property_at_from_end )
             {
                 export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
                 export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_ID_FRAGMENT_SOURCE_END );
             }
             else
             {
-                export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_classifier_id );
+                export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_end_id );
             }
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_END );
 
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
             
-            if ( ( ! data_id_is_valid( &from_feature_id ) ) && fake_property_ends )
+            if ( fake_property_at_from_end )
             {
                 export_err |= xmi_element_writer_private_fake_memberend ( this_,
                                                                           relation_id,
                                                                           relation_type,
-                                                                          data_id_is_valid( &from_feature_id )
-                                                                          ? from_feature_id
-                                                                          : from_classifier_id,
+                                                                          from_end_id,
+                                                                          from_c_type,
+                                                                          from_f_type,
                                                                           false /* = is_target_end */
                                                                         );
             }
         }
 
         /* destination */
+        /* determine from type tag */
+        const char* to_type_tag;
+        const int to_type_err
+            = xmi_type_converter_get_xmi_to_property_of_relationship ( &((*this_).xmi_types),
+                                                                       parent_type,
+                                                                       relation_type,
+                                                                       to_c_type,
+                                                                       to_f_type,
+                                                                       &to_type_tag
+                                                                     );
+        if ( to_type_err != 0 )
+        {
+            /* The caller requested to write a relationship of illegal target end type */
+            TRACE_INFO("xmi_element_writer: request to write a relationship connecting an illegal target end type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_illegal_relationship_end ( &((*this_).atom_writer),
+                                                                            relation_id,
+                                                                            relation_type,
+                                                                            parent_type,
+                                                                            false /* = from_end */,
+                                                                            to_c_type,
+                                                                            to_f_type
+                                                                          );                
+        }
+            
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
-        const char* to_type = xmi_type_converter_get_xmi_to_property_of_relationship ( &((*this_).xmi_types),
-                                                                                       parent_type,
-                                                                                       relation_type
-                                                                                     );
-        export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), to_type );
+        export_err |= xml_writer_write_xml_enc ( &((*this_).xml_writer), to_type_tag );
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
 
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_START );
-        if ( data_id_is_valid( &to_feature_id ) )
-        {
-            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_feature_id );
-        }
-        else if ( fake_property_ends )
+        if ( fake_property_at_to_end )
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
             export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_ID_FRAGMENT_TARGET_END );
         }
         else
         {
-            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_classifier_id );
+            export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_end_id );
         }
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_XML_ATTR_IDREF_END );
 
         export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_END );
 
-        if ( ( ! data_id_is_valid( &to_feature_id ) ) && fake_property_ends )
+        if ( fake_property_at_to_end )
         {
             export_err |= xmi_element_writer_private_fake_memberend ( this_,
                                                                       relation_id,
                                                                       relation_type,
-                                                                      data_id_is_valid( &to_feature_id ) 
-                                                                      ? to_feature_id
-                                                                      : to_classifier_id,
+                                                                      to_end_id,
+                                                                      to_c_type,
+                                                                      to_f_type,
                                                                       true /* = is_target_end */
                                                                     );
         }
@@ -987,6 +1057,8 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
                                                 data_id_t relationship_id,
                                                 data_relationship_type_t relationship_type,
                                                 data_id_t end_object_id,
+                                                data_classifier_type_t end_classifier_type,
+                                                data_feature_type_t end_feature_type,
                                                 bool is_target_end )
 {
     TRACE_BEGIN();
@@ -997,7 +1069,14 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
         ||( relationship_type == DATA_RELATIONSHIP_TYPE_UML_COMPOSITION );
     const bool is_aggregation 
         = ( relationship_type == DATA_RELATIONSHIP_TYPE_UML_AGGREGATION );
-    
+
+    const xmi_element_info_t *classifier_info
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, 
+                                               end_classifier_type, 
+                                               DATA_CLASSIFIER_TYPE_PACKAGE /* if state or activity context does not matter here */ 
+                                             );
+    assert ( classifier_info != NULL );
+        
     /* begin start member-end element */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_START_TAG_START );
@@ -1047,7 +1126,19 @@ int xmi_element_writer_private_fake_memberend ( xmi_element_writer_t *this_,
     /* start type element */
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_NL );
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_EMPTY_TAG_START );
-    export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_TYPE_ELEMENT );
+    if (( end_feature_type == DATA_FEATURE_TYPE_PROVIDED_INTERFACE )||( end_feature_type == DATA_FEATURE_TYPE_REQUIRED_INTERFACE )
+        ||(( end_feature_type == DATA_FEATURE_TYPE_VOID )&&( end_classifier_type == DATA_CLASSIFIER_TYPE_INTERFACE )))
+    {
+        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_INTERFACE_ELEMENT );
+    }
+    else if (( end_feature_type == DATA_FEATURE_TYPE_VOID ) && xmi_element_info_is_a_class( classifier_info ) )
+    {
+        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_CLASS_ELEMENT );
+    }
+    else
+    {
+        export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XMI_ELEMENT_PART_PROPERTY_TYPE_ELEMENT );
+    }
     export_err |= xml_writer_write_plain ( &((*this_).xml_writer), XML_WRITER_ATTR_SEPARATOR );
     
     /* write id-ref attribute */
