@@ -78,9 +78,11 @@ int xmi_interaction_writer_start_diagram( xmi_interaction_writer_t *this_,
             /* update export statistics */
             data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_CLASSIFIER, DATA_STAT_SERIES_WARNING );
             /* inform the user via an XML comment: */
-            export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\n<!-- COMMENT ON UML-CONFORMANCE: Unsuitable nested type of " );
-            export_err |= xml_writer_write_plain_id( (*this_).xml_writer, diagram_id );
-            export_err |= xml_writer_write_plain ( (*this_).xml_writer, " -->" );
+            export_err |= xmi_atom_writer_report_illegal_container( &((*this_).atom_writer),
+                                                                    diagram_id,
+                                                                    DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake child type */
+                                                                    parent_type
+                                                                  );
             /* use a fallback */
             nesting_property = XMI_ELEMENT_PART_FALLBACK_NESTING_ELEMENT;
         }
@@ -95,6 +97,7 @@ int xmi_interaction_writer_start_diagram( xmi_interaction_writer_t *this_,
         /* write type attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
+        /* TODO possibly a uml:Collaboration needs to be placed arounf the DATA_CLASSIFIER_TYPE_INTERACTION? */
         const char* c_type = xmi_type_converter_get_xmi_type_of_classifier ( &((*this_).xmi_types),
                                                                              parent_type,
                                                                              DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake child type */
@@ -130,8 +133,8 @@ int xmi_interaction_writer_start_diagram( xmi_interaction_writer_t *this_,
                                                            );
         }
 
-        /* update export statistics */
-        data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_DIAGRAM, DATA_STAT_SERIES_EXPORTED );
+        /* update export statistics, report as classifier because DATA_CLASSIFIER_TYPE_INTERACTION is a classifier */
+        data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_CLASSIFIER, DATA_STAT_SERIES_EXPORTED );
     }
 
     TRACE_END_ERR( export_err );
@@ -215,10 +218,14 @@ int xmi_interaction_writer_assemble_feature( xmi_interaction_writer_t *this_,
     return export_err;
 }
 
-int xmi_ineraction_writer_assemble_relationship( xmi_interaction_writer_t *this_,
-                                                 data_id_t interaction_id,
-                                                 data_classifier_type_t parent_type,
-                                                 const data_relationship_t *relation_ptr )
+int xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_t *this_,
+                                                  data_id_t interaction_id,
+                                                  data_classifier_type_t parent_type,
+                                                  const data_relationship_t *relation_ptr,
+                                                  data_classifier_type_t from_c_type,
+                                                  data_feature_type_t from_f_type,
+                                                  data_classifier_type_t to_c_type,
+                                                  data_feature_type_t to_f_type )
 {
     TRACE_BEGIN();
     assert ( NULL != relation_ptr );
@@ -246,29 +253,53 @@ int xmi_ineraction_writer_assemble_relationship( xmi_interaction_writer_t *this_
         }
 
         /* source */
+        /* determine from type tag */
+        const char* from_type_tag;
+        const int from_type_err
+            = xmi_type_converter_get_xmi_from_property_of_relationship ( &((*this_).xmi_types),
+                                                                         parent_type,
+                                                                         relation_type,
+                                                                         from_c_type,
+                                                                         from_f_type,
+                                                                         &from_type_tag
+                                                                       );
+        if ( from_type_err != 0 )
+        {
+            /* The caller requested to write a relationship of illegal source end type */
+            TRACE_INFO("xmi_interaction_writer: request to write a relationship connecting an illegal source end type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_illegal_relationship_end ( &((*this_).atom_writer),
+                                                                            relation_id,
+                                                                            relation_type,
+                                                                            parent_type,
+                                                                            true /* = from_end */,
+                                                                            from_c_type,
+                                                                            from_f_type
+                                                                          );                
+        }
+
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_START );
-        const char* from_type = xmi_type_converter_get_xmi_from_property_of_relationship ( &((*this_).xmi_types),
-                                                                                           parent_type,
-                                                                                           relation_type
-                                                                                         );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, from_type );
+        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, from_type_tag );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
         
         /* write type attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "MessageOccurrenceSpecification" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "#source" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_SOURCE_END );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "covered=\"" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_START );
         if ( data_id_is_valid( &from_feature_id ) )
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_feature_id );
@@ -277,7 +308,8 @@ int xmi_ineraction_writer_assemble_relationship( xmi_interaction_writer_t *this_
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_classifier_id );
         }
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_END );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
 
         /* write lifeline id attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
@@ -287,29 +319,53 @@ int xmi_ineraction_writer_assemble_relationship( xmi_interaction_writer_t *this_
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_END );
 
         /* destination */
+        /* determine from type tag */
+        const char* to_type_tag;
+        const int to_type_err
+            = xmi_type_converter_get_xmi_to_property_of_relationship ( &((*this_).xmi_types),
+                                                                       parent_type,
+                                                                       relation_type,
+                                                                       to_c_type,
+                                                                       to_f_type,
+                                                                       &to_type_tag
+                                                                     );
+        if ( to_type_err != 0 )
+        {
+            /* The caller requested to write a relationship of illegal target end type */
+            TRACE_INFO("xmi_interaction_writer: request to write a relationship connecting an illegal target end type!")
+            /* update export statistics */
+            data_stat_inc_count ( (*this_).export_stat, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING );
+            /* inform the user via an XML comment: */
+            export_err |= xmi_atom_writer_report_illegal_relationship_end ( &((*this_).atom_writer),
+                                                                            relation_id,
+                                                                            relation_type,
+                                                                            parent_type,
+                                                                            false /* = from_end */,
+                                                                            to_c_type,
+                                                                            to_f_type
+                                                                          );                
+        }
+            
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_START );
-        const char* to_type = xmi_type_converter_get_xmi_to_property_of_relationship ( &((*this_).xmi_types),
-                                                                                       parent_type,
-                                                                                       relation_type
-                                                                                     );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, to_type );
+        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, to_type_tag );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
 
         /* write type attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "MessageOccurrenceSpecification" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "#dest" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_TARGET_END );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "covered=\"" );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_START );
         if ( data_id_is_valid( &to_feature_id ) )
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_feature_id );
@@ -318,11 +374,12 @@ int xmi_ineraction_writer_assemble_relationship( xmi_interaction_writer_t *this_
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_classifier_id );
         }
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_END );
+        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
 
         /* write lifeline id attribute */
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "90001" );
+        export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), interaction_id );
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
 
         export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_END );
