@@ -26,11 +26,11 @@ xmi_spec_t xmi_type_converter_get_xmi_spec_of_classifier ( xmi_type_converter_t
 {
     TRACE_BEGIN();
 
-    const xmi_element_info_t *e_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, c_type, false /*this parameter does not matter for this use case*/ );
-    assert ( e_info != NULL );
+    const xmi_element_info_t *classifier_info
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, c_type, DATA_CLASSIFIER_TYPE_PACKAGE /*this parameter does not matter for this use case*/ );
+    assert ( classifier_info != NULL );
     const xmi_spec_t result
-        = (*e_info).specification;
+        = (*classifier_info).specification;
 
     TRACE_END();
     return result;
@@ -43,13 +43,13 @@ const char* xmi_type_converter_get_xmi_type_of_classifier ( xmi_type_converter_t
 {
     TRACE_BEGIN();
 
-    const xmi_element_info_t *e_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, c_type, (parent_type==DATA_CLASSIFIER_TYPE_STATE) );
-    assert ( e_info != NULL );
+    const xmi_element_info_t *classifier_info
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, c_type, parent_type );
+    assert ( classifier_info != NULL );
     const char* result
-        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*e_info).profile_name != NULL ))
-        ? (*e_info).profile_name
-        : (*e_info).base_name;
+        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*classifier_info).profile_name != NULL ))
+        ? (*classifier_info).profile_name
+        : (*classifier_info).base_name;
     assert ( result != NULL );
 
     TRACE_END();
@@ -66,14 +66,14 @@ int xmi_type_converter_get_xmi_nesting_property_of_classifier ( xmi_type_convert
     const char* result = NULL;
 
     const xmi_element_info_t *parent_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type, false /*TODO: fix guess*/ );
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type, DATA_CLASSIFIER_TYPE_PACKAGE /*TODO: fix guess*/ );
     assert ( parent_info != NULL );
     const bool p_is_state = ( parent_type == DATA_CLASSIFIER_TYPE_STATE );
     const bool p_is_activity = ( parent_type == DATA_CLASSIFIER_TYPE_ACTIVITY );
     const bool p_is_interruptable_region = ( parent_type == DATA_CLASSIFIER_TYPE_DYN_INTERRUPTABLE_REGION );
     const bool p_is_interaction = ( parent_type == DATA_CLASSIFIER_TYPE_INTERACTION );
     const xmi_element_info_t *child_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, child_type, p_is_state );
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, child_type, parent_type );
     assert ( child_info != NULL );
 
     if ( xmi_element_info_is_a_package(parent_info) &&  xmi_element_info_is_a_packageable_element(child_info) )
@@ -146,7 +146,7 @@ int xmi_type_converter_get_xmi_nesting_property_of_classifier ( xmi_type_convert
 
 int xmi_type_converter_get_xmi_owning_property_of_feature ( xmi_type_converter_t *this_,
                                                             data_classifier_type_t parent_type,
-                                                            data_feature_type_t f_type,
+                                                            data_feature_type_t feature_type,
                                                             char const * *out_xmi_name )
 {
     TRACE_BEGIN();
@@ -155,10 +155,10 @@ int xmi_type_converter_get_xmi_owning_property_of_feature ( xmi_type_converter_t
     int result_err = -1;
 
     const xmi_element_info_t *parent_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type, false /*TODO: fix guess*/ );
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, parent_type, DATA_CLASSIFIER_TYPE_PACKAGE /*TODO: fix guess*/ );
     assert ( parent_info != NULL );
 
-    switch ( f_type )
+    switch ( feature_type )
     {
         case DATA_FEATURE_TYPE_PROPERTY:
         {
@@ -182,10 +182,22 @@ int xmi_type_converter_get_xmi_owning_property_of_feature ( xmi_type_converter_t
 
         case DATA_FEATURE_TYPE_PORT:
         {
-            /* spec: https://www.omg.org/spec/UML/2.5.1/PDF ch 11.8.13.5 */
-            result = "ownedPort";
-            result_err = xmi_element_info_is_a_encapsulated_classifier(parent_info) ? 0 : -1;
-            /*TODO ownedPort is a derived value*/
+            const bool is_behavioral_parent = data_classifier_type_is_behavioral( parent_type );
+            if ( is_behavioral_parent )
+            {
+                const bool p_is_activity_or_group 
+                    = ( parent_type == DATA_CLASSIFIER_TYPE_ACTIVITY )||( parent_type == DATA_CLASSIFIER_TYPE_DYN_INTERRUPTABLE_REGION );
+                /* spec: https://www.omg.org/spec/UML/2.5.1/PDF chapter 15.7.1.5 */
+                result = "node";
+                result_err = p_is_activity_or_group ? 0 : -1;
+            }
+            else
+            {
+                /* spec: https://www.omg.org/spec/UML/2.5.1/PDF ch 11.8.13.5 */
+                result = "ownedPort";
+                result_err = xmi_element_info_is_a_encapsulated_classifier(parent_info) ? 0 : -1;
+                /*TODO ownedPort is a derived value*/
+            }
         }
         break;
 
@@ -233,7 +245,7 @@ int xmi_type_converter_get_xmi_owning_property_of_feature ( xmi_type_converter_t
 
         default:
         {
-            TSLOG_ERROR_INT( "switch case statement for data_relationship_type_t incomplete", f_type );
+            TSLOG_ERROR_INT( "switch case statement for data_relationship_type_t incomplete", feature_type );
             assert( 0 );
         }
         break;
@@ -254,7 +266,7 @@ int xmi_type_converter_get_xmi_nesting_property_of_relationship ( xmi_type_conve
     const char* result = NULL;
 
     const xmi_element_info_t *host_info
-        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, hosting_type, false /*TODO: fix guess*/ );
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, hosting_type, DATA_CLASSIFIER_TYPE_PACKAGE /*TODO: fix guess*/ );
     assert ( host_info != NULL );
     const bool host_is_activity = ( hosting_type == DATA_CLASSIFIER_TYPE_ACTIVITY );
     /*const bool host_is_interface = ( hosting_type == DATA_CLASSIFIER_TYPE_INTERFACE );*/
@@ -262,6 +274,7 @@ int xmi_type_converter_get_xmi_nesting_property_of_relationship ( xmi_type_conve
     const bool host_is_usecase = ( hosting_type == DATA_CLASSIFIER_TYPE_USE_CASE );
     const bool host_is_state = ( hosting_type == DATA_CLASSIFIER_TYPE_STATE );
     const bool host_is_interaction = ( hosting_type == DATA_CLASSIFIER_TYPE_INTERACTION );
+    const bool host_is_comment = ( hosting_type == DATA_CLASSIFIER_TYPE_COMMENT );
     const xmi_element_info_t *child_info
         = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard, child_type, host_is_state );
     assert ( child_info != NULL );
@@ -316,6 +329,11 @@ int xmi_type_converter_get_xmi_nesting_property_of_relationship ( xmi_type_conve
         /* spec: https://www.omg.org/spec/UML/2.5.1/PDF chapter 17.4 */
         result = "message";
     }
+    else if ( host_is_comment && (child_type==DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY) )
+    {
+        /* spec: https://www.omg.org/spec/UML/2.5.1/PDF chapter 7.8.2 */
+        result = "annotatedElement";
+    }
 
     *out_xmi_name = (result==NULL) ? "" : result;
     const int result_err = (result==NULL) ? -1 : 0;
@@ -325,7 +343,7 @@ int xmi_type_converter_get_xmi_nesting_property_of_relationship ( xmi_type_conve
 
 /* ================================ FEATURE ================================ */
 
-xmi_spec_t xmi_type_converter_get_xmi_spec_of_feature ( xmi_type_converter_t *this_, data_feature_type_t f_type )
+xmi_spec_t xmi_type_converter_get_xmi_spec_of_feature ( xmi_type_converter_t *this_, data_feature_type_t feature_type )
 {
     TRACE_BEGIN();
     xmi_spec_t result = XMI_SPEC_UML;  /* all currently known features are defined in the uml specification */
@@ -335,18 +353,20 @@ xmi_spec_t xmi_type_converter_get_xmi_spec_of_feature ( xmi_type_converter_t *th
 }
 
 const char* xmi_type_converter_get_xmi_type_of_feature ( xmi_type_converter_t *this_,
-                                                         data_feature_type_t f_type,
+                                                         data_classifier_type_t parent_type,
+                                                         data_feature_type_t feature_type,
+                                                         xmi_direction_t flow_direction,
                                                          xmi_spec_t spec )
 {
     TRACE_BEGIN();
 
-    const xmi_element_info_t *e_info
-        = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, f_type );
-    assert ( e_info != NULL );
+    const xmi_element_info_t *feature_info
+        = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, feature_type, flow_direction, parent_type );
+    assert ( feature_info != NULL );
     const char* result
-        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*e_info).profile_name != NULL ))
-        ? (*e_info).profile_name
-        : (*e_info).base_name;
+        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*feature_info).profile_name != NULL ))
+        ? (*feature_info).profile_name
+        : (*feature_info).base_name;
     assert ( result != NULL );
 
     TRACE_END();
@@ -359,11 +379,11 @@ xmi_spec_t xmi_type_converter_get_xmi_spec_of_relationship ( xmi_type_converter_
 {
     TRACE_BEGIN();
 
-    const xmi_element_info_t *e_info
+    const xmi_element_info_t *rel_info
         = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard, r_type, false /*this parameter does not matter for this use case*/ );
-    assert ( e_info != NULL );
+    assert ( rel_info != NULL );
     const xmi_spec_t result
-        = (*e_info).specification;
+        = (*rel_info).specification;
 
     TRACE_END();
     return result;
@@ -377,38 +397,177 @@ const char* xmi_type_converter_get_xmi_type_of_relationship ( xmi_type_converter
     TRACE_BEGIN();
 
     const bool host_is_state = ( hosting_type == DATA_CLASSIFIER_TYPE_STATE );
-    const xmi_element_info_t *e_info
+    const xmi_element_info_t *rel_info
         = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard, r_type, host_is_state );
-    assert ( e_info != NULL );
+    assert ( rel_info != NULL );
     const char* result
-        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*e_info).profile_name != NULL ))
-        ? (*e_info).profile_name
-        : (*e_info).base_name;
+        = (( (spec & (XMI_SPEC_SYSML|XMI_SPEC_STANDARD)) != 0 )&&( (*rel_info).profile_name != NULL ))
+        ? (*rel_info).profile_name
+        : (*rel_info).base_name;
     assert ( result != NULL );
 
     TRACE_END();
     return result;
 }
 
-const char* xmi_type_converter_private_get_xmi_end_property_of_relationship ( xmi_type_converter_t *this_,
-                                                                              data_classifier_type_t hosting_type,
-                                                                              data_relationship_type_t r_type,
-                                                                              bool from_end )
+int xmi_type_converter_private_get_xmi_end_property_of_relationship ( xmi_type_converter_t *this_,
+                                                                      data_classifier_type_t hosting_type,
+                                                                      data_relationship_type_t rel_type,
+                                                                      bool from_end,
+                                                                      data_classifier_type_t end_classifier_type,
+                                                                      data_feature_type_t end_feature_type,
+                                                                      char const * *out_xmi_name )
 {
     TRACE_BEGIN();
+    assert( out_xmi_name != NULL );
+    int err = 0;
 
     const bool host_is_state = ( hosting_type == DATA_CLASSIFIER_TYPE_STATE );
-    const xmi_element_info_t *e_info
-        = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard, r_type, host_is_state );
-    assert ( e_info != NULL );
+    const xmi_element_info_t *rel_info
+        = xmi_element_info_map_get_relationship( &xmi_element_info_map_standard, rel_type, host_is_state );
+    assert ( rel_info != NULL );
     const char* result
         = ( from_end )
-        ? (*e_info).property_from
-        : (*e_info).property_to;
+        ? (*rel_info).property_from
+        : (*rel_info).property_to;
     assert ( result != NULL );
 
-    TRACE_END();
-    return result;
+    *out_xmi_name = ( result == NULL ) ? "" : result;
+    err = ( result == NULL ) ? -1 : 0;
+    
+    const xmi_element_info_t *classifier_info
+        = xmi_element_info_map_get_classifier( &xmi_element_info_map_standard, end_classifier_type, hosting_type );
+    assert ( classifier_info != NULL );
+    
+    if ( end_feature_type == DATA_FEATURE_TYPE_VOID )
+    {
+        /* relationship end is at a classifier */
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_CONTROL_FLOW and DATA_RELATIONSHIP_TYPE_UML_OBJECT_FLOW */
+        if ( xmi_element_info_is_a_transition( rel_info ) && xmi_element_info_is_a_vertex( classifier_info ) )
+        {
+            /* valid relationship according to uml 2.5.1 spec, chapter 14.5.11 */
+        }
+        else if ( xmi_element_info_is_a_activity_edge( rel_info ) && xmi_element_info_is_a_activity_node( classifier_info ) )
+        {
+            /* valid relationship according to uml 2.5.1 spec, chapter 15.7.2 */
+        }
+        else if ( xmi_element_info_is_a_activity_edge( rel_info ) && ( end_classifier_type == DATA_CLASSIFIER_TYPE_ACTIVITY ))
+        {
+            /* valid relationship according to uml 2.5.1 spec, chapter 16.14.55 */
+        }
+
+        /* DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY, DATA_RELATIONSHIP_TYPE_UML_REALIZATION, DATA_RELATIONSHIP_TYPE_UML_MANIFEST, */
+        /* DATA_RELATIONSHIP_TYPE_UML_DEPLOY, DATA_RELATIONSHIP_TYPE_UML_REFINE,  DATA_RELATIONSHIP_TYPE_UML_TRACE */
+        else if ( xmi_element_info_is_a_dependency( rel_info ) && xmi_element_info_is_a_named_element( classifier_info ) )
+        {
+            /* a dependency can connect any named elements according to uml 2.5.1 spec, chapter 7.8.4  */
+        }
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_ASSOCIATION, DATA_RELATIONSHIP_TYPE_UML_AGGREGATION, DATA_RELATIONSHIP_TYPE_UML_COMPOSITION, */
+        /* DATA_RELATIONSHIP_TYPE_UML_COMMUNICATION_PATH, DATA_RELATIONSHIP_TYPE_UML_CONTAINMENT */
+        else if ( xmi_element_info_is_a_association( rel_info ) && xmi_element_info_is_a_class( classifier_info ) )
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property can connect a class according to uml 2.5.1 spec, chapter 9.9.17  */
+        }
+        else if ( xmi_element_info_is_a_association( rel_info ) && ( end_classifier_type == DATA_CLASSIFIER_TYPE_INTERFACE ))
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property can connect an interface according to uml 2.5.1 spec, chapter 9.9.17  */
+        }
+        else if ( xmi_element_info_is_a_association( rel_info ) && xmi_element_info_is_a_classifier( classifier_info ) )
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property is a typedelelemnt and can therefore connect a classifier(type) according to uml 2.5.1 spec, chapter 7.8.22  */
+        }
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_EXTEND and DATA_RELATIONSHIP_TYPE_UML_INCLUDE */
+        else if (( rel_type == DATA_RELATIONSHIP_TYPE_UML_EXTEND ) && ( end_classifier_type == DATA_CLASSIFIER_TYPE_USE_CASE ))
+        {
+            /* an extend directed relationship can connect to a use case according to uml 2.5.1 spec, chapter 18.2.2  */
+        }
+        else if (( rel_type == DATA_RELATIONSHIP_TYPE_UML_INCLUDE ) && ( end_classifier_type == DATA_CLASSIFIER_TYPE_USE_CASE ))
+        {
+            /* an include directed relationship can connect to a use case according to uml 2.5.1 spec, chapter 18.2.4  */
+        }
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_GENERALIZATION */
+        else if (( rel_type == DATA_RELATIONSHIP_TYPE_UML_GENERALIZATION ) && xmi_element_info_is_a_classifier( classifier_info ) )
+        {
+            /* a generalization can connect any classifiers according to uml 2.5.1 spec, chapter 9.9.7  */
+        }
+
+        else
+        {
+            /* no valid end type for given relationship type */
+            err = -1;
+        }
+    }
+    else
+    {
+        /* relationship end is at feature */
+        const xmi_element_info_t *feature_info
+            = xmi_element_info_map_get_feature( &xmi_element_info_map_standard, 
+                                                end_feature_type, 
+                                                XMI_DIRECTION_UNSPECIFIED /*doe not matter here*/, 
+                                                end_classifier_type 
+                                              );
+        assert ( feature_info != NULL );
+
+        if ( xmi_element_info_is_a_activity_edge( rel_info ) && xmi_element_info_is_a_activity_node( feature_info ) )
+        {
+            /* valid relationship according to uml 2.5.1 spec, chapter 15.7.2 */
+        }
+
+        /* DATA_RELATIONSHIP_TYPE_UML_ASYNC_CALL or DATA_RELATIONSHIP_TYPE_UML_SYNC_CALL or DATA_RELATIONSHIP_TYPE_UML_RETURN_CALL */
+        else if ( xmi_element_info_is_a_message ( rel_info ) && ( end_feature_type == DATA_FEATURE_TYPE_LIFELINE ))
+        {
+            /* valid relationship according to uml 2.5.1 spec, chapter 17.12.23 */
+        }
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_DEPENDENCY, DATA_RELATIONSHIP_TYPE_UML_REALIZATION, DATA_RELATIONSHIP_TYPE_UML_MANIFEST, */
+        /* DATA_RELATIONSHIP_TYPE_UML_DEPLOY, DATA_RELATIONSHIP_TYPE_UML_REFINE,  DATA_RELATIONSHIP_TYPE_UML_TRACE */
+        else if ( xmi_element_info_is_a_dependency( rel_info ) && xmi_element_info_is_a_named_element( feature_info ) )
+        {
+            /* a dependency can connect any named elements according to uml 2.5.1 spec, chapter 7.8.4  */
+        }
+        
+        /* DATA_RELATIONSHIP_TYPE_UML_ASSOCIATION, DATA_RELATIONSHIP_TYPE_UML_AGGREGATION, DATA_RELATIONSHIP_TYPE_UML_COMPOSITION, */
+        /* DATA_RELATIONSHIP_TYPE_UML_COMMUNICATION_PATH, DATA_RELATIONSHIP_TYPE_UML_CONTAINMENT */
+        else if ( xmi_element_info_is_a_association( rel_info ) && xmi_element_info_is_a_class( feature_info ) )
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property can connect a class according to uml 2.5.1 spec, chapter 9.9.17  */
+        }
+        else if ( xmi_element_info_is_a_association( rel_info ) 
+            && (( end_feature_type ==  DATA_FEATURE_TYPE_PROVIDED_INTERFACE )||( end_feature_type == DATA_FEATURE_TYPE_REQUIRED_INTERFACE )))
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property can connect an interface according to uml 2.5.1 spec, chapter 9.9.17  */
+        }
+        else if ( xmi_element_info_is_a_association( rel_info ) && xmi_element_info_is_a_classifier( feature_info ) )
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a property is a typedelelemnt and can therefore connect a classifier(type) according to uml 2.5.1 spec, chapter 7.8.22  */
+        }
+        else if ( xmi_element_info_is_a_association( rel_info ) 
+            && (( end_feature_type ==  DATA_FEATURE_TYPE_PROPERTY )||( end_feature_type == DATA_FEATURE_TYPE_PORT )))
+        {
+            /* an association can connect to a propoerty according to uml 2.5.1 spec, chapter 11.8.1  */
+            /* a port is a property */
+        }
+        
+        else
+        {
+            /* no valid end type for given relationship type */
+            err = -1;
+        }
+        
+    }
+    
+    TRACE_END_ERR( err );
+    return err;
 }
 
 
