@@ -12,7 +12,7 @@
 /* human readable version */
 #define META_INFO_PROGRAM_NAME_STR "crystal facet uml"
 /* machine readable version */
-#define META_INFO_PROGRAM_ID_STR "crystal_facet_uml"
+#define META_INFO_PROGRAM_ID_STR "crystal-facet-uml"
 #define META_INFO_COPYRIGHT_STR /*Copyright*/ "2016-2020 Andreas Warnke"
 #ifdef __linux__
 #define META_INFO_LICENSE_STR "Apache-2.0"  /* sqlite3 linked dynamicyally */
