@@ -223,8 +223,10 @@ void pencil_feature_layouter_private_layout_port ( pencil_feature_layouter_t *th
     list_order = data_feature_get_list_order( the_feature );
 
     /* position the port icon */
+    const bool is_sysml_constraint_block = (classifier_type == DATA_CLASSIFIER_TYPE_CONSTRAINT_BLOCK);
+    const bool is_behavioral = data_classifier_type_is_behavioral( classifier_type );
     const double outwards_distance 
-        = (classifier_type == DATA_CLASSIFIER_TYPE_CONSTRAINT_BLOCK) ? 0 : (0.5*port_icon_size);
+        = is_sysml_constraint_block ? 0.0 : is_behavioral ? port_icon_size : (0.5*port_icon_size);
     double port_icon_left;
     double port_icon_top;
     if ( list_order < 0 )
@@ -427,7 +429,7 @@ void pencil_feature_layouter_private_layout_prop_or_op ( pencil_feature_layouter
                 {
                     const bool is_above = (( data_feature_get_list_order( f_probe_data ) < data_feature_get_list_order( the_feature ))
                         || (( data_feature_get_list_order( f_probe_data ) == data_feature_get_list_order( the_feature ) )
-                            && ( data_feature_get_id( f_probe_data ) < data_feature_get_id( the_feature ) )));
+                            && ( data_feature_get_row_id( f_probe_data ) < data_feature_get_row_id( the_feature ) )));
                     if ( is_above )
                     {
                         count_features_above ++;
