@@ -101,7 +101,7 @@ void pencil_layout_data_private_init_features( pencil_layout_data_t *this_ )
 
         if ( ( NULL != feature_data ) && data_feature_is_valid( feature_data ) )
         {
-            const data_row_id_t feature_id = data_feature_get_id( feature_data );
+            const data_row_id_t feature_id = data_feature_get_row_id( feature_data );
             const bool show = data_rules_diagram_shows_feature ( &((*this_).filter_rules),
                                                                  (*this_).input_data,
                                                                  feature_id
@@ -182,7 +182,7 @@ void pencil_layout_data_private_init_relationships( pencil_layout_data_t *this_
         {
             const bool show = data_rules_diagram_shows_relationship ( &((*this_).filter_rules),
                                                                       (*this_).input_data,
-                                                                      data_relationship_get_id( relationship_data )
+                                                                      data_relationship_get_row_id( relationship_data )
             );
 
             if ( show )
@@ -227,10 +227,10 @@ uint32_t pencil_layout_data_private_init_relationship( pencil_layout_data_t *thi
     assert ( NULL != io_dropped_relationships );
     uint32_t layout_relationship_count = 0;
 
-    const data_row_id_t from_classifier_id = data_relationship_get_from_classifier_id( relationship_data );
-    const data_row_id_t to_classifier_id = data_relationship_get_to_classifier_id( relationship_data );
-    const data_row_id_t from_feature_id = data_relationship_get_from_feature_id( relationship_data );
-    const data_row_id_t to_feature_id = data_relationship_get_to_feature_id( relationship_data );
+    const data_row_id_t from_classifier_id = data_relationship_get_from_classifier_row_id( relationship_data );
+    const data_row_id_t to_classifier_id = data_relationship_get_to_classifier_row_id( relationship_data );
+    const data_row_id_t from_feature_id = data_relationship_get_from_feature_row_id( relationship_data );
+    const data_row_id_t to_feature_id = data_relationship_get_to_feature_row_id( relationship_data );
 
     if ( DATA_ROW_ID_VOID == from_feature_id )  /* search source(from) in classifiers */
     {
@@ -281,7 +281,7 @@ uint32_t pencil_layout_data_private_init_relationship( pencil_layout_data_t *thi
                         const bool one_to_feature_found = ( to_feature_id == layout_feature_get_feature_id( probe4_feature ) );
                         if ( one_to_feature_found )
                         {
-                            const bool to_feature_ok = ( to_classifier_id == data_feature_get_classifier_id(layout_feature_get_data_const( probe4_feature )) );
+                            const bool to_feature_ok = ( to_classifier_id == data_feature_get_classifier_row_id(layout_feature_get_data_const( probe4_feature )) );
                             if ( to_feature_ok )
                             {
                                 if ( (*this_).relationship_count < PENCIL_LAYOUT_DATA_MAX_RELATIONSHIPS )
@@ -321,7 +321,7 @@ uint32_t pencil_layout_data_private_init_relationship( pencil_layout_data_t *thi
             const bool one_from_feature_found = ( from_feature_id == layout_feature_get_feature_id( probe3_feature ) );
             if ( one_from_feature_found )
             {
-                const bool from_feature_ok = ( from_classifier_id == data_feature_get_classifier_id(layout_feature_get_data_const( probe3_feature )) );
+                const bool from_feature_ok = ( from_classifier_id == data_feature_get_classifier_row_id(layout_feature_get_data_const( probe3_feature )) );
                 if ( from_feature_ok )
                 {
                     if ( DATA_ROW_ID_VOID == to_feature_id )  /* search destination(to) in classifiers */
@@ -363,7 +363,7 @@ uint32_t pencil_layout_data_private_init_relationship( pencil_layout_data_t *thi
                             const bool one_to_feature_found = ( to_feature_id == layout_feature_get_feature_id( probe5_feature ) );
                             if ( one_to_feature_found )
                             {
-                                const bool to_feature_ok = ( to_classifier_id == data_feature_get_classifier_id(layout_feature_get_data_const( probe5_feature )) );
+                                const bool to_feature_ok = ( to_classifier_id == data_feature_get_classifier_row_id(layout_feature_get_data_const( probe5_feature )) );
                                 if ( to_feature_ok )
                                 {
                                     if ( (*this_).relationship_count < PENCIL_LAYOUT_DATA_MAX_RELATIONSHIPS )
